@@ -78,7 +78,7 @@ static ECalBackendClass *parent_class = NULL;
 
 #define	d(x)
 
-G_DEFINE_TYPE (CalBackendWCAP, cal_backend_wcap,  E_TYPE_CAL_BACKEND_SYNC);
+G_DEFINE_TYPE (CalBackendWCAP, cal_backend_wcap,  E_TYPE_CAL_BACKEND_SYNC)
 
 SunOneConnection *
 cal_backend_wcap_get_connection (CalBackendWCAP *wcap)
