@@ -51,7 +51,7 @@ static SunOneConnection * sunone_account_connect (SunOneAccount *account);
 static GObjectClass *parent_class = NULL;
 static gboolean getting_password = FALSE;
 
-G_DEFINE_TYPE (SunOneAccount, sunone_account, G_TYPE_OBJECT);
+G_DEFINE_TYPE (SunOneAccount, sunone_account, G_TYPE_OBJECT)
 
 static void
 sunone_account_class_init (SunOneAccountClass *klass)
