@@ -17,7 +17,7 @@
 
 #include <string.h>
 #include <libsoup/soup.h>
-#include <e-util/e-time-utils.h>
+#include <libedataserver/e-time-utils.h>
 
 #include "sunone-connection.h"
 #include "sunone-message.h"
@@ -305,7 +305,7 @@ append_to_query_attendees (SoupUri *uri, const char *param, GSList *attendee_lis
 			if(!strcasecmp (email, attendee->value + 7)) {
 				g_string_append_printf (string, "^%s;", calid);
 			} else
-				g_string_append_printf (string, "^%s;", attendee->value + 7);
+				g_string_append_printf (string, "^%s;", attendee->value);
 
 		} else
 			g_string_append_printf (string, "^%s;", attendee->value);			
@@ -584,7 +584,7 @@ type_to_string (SunOneCompType type)
 	return "all";
 }
 
-G_DEFINE_TYPE (SunOneConnection, sunone_connection, G_TYPE_OBJECT);
+G_DEFINE_TYPE (SunOneConnection, sunone_connection, G_TYPE_OBJECT)
 
 static void
 sunone_connection_class_init (SunOneConnectionClass *klass)
