@@ -56,7 +56,7 @@ static GType col_types[] = {
 static gboolean sft_tree_button_press (GtkTreeView *treeview, GdkEventButton *event, SunOneFolderTree *tree);
 static gboolean sft_tree_popup_menu (GtkWidget *widget, SunOneFolderTree *tree);
 
-G_DEFINE_TYPE (SunOneFolderTree, sunone_folder_tree, G_TYPE_OBJECT);
+G_DEFINE_TYPE (SunOneFolderTree, sunone_folder_tree, G_TYPE_OBJECT)
 
 static void
 destroy_page (gpointer key, gpointer value, gpointer user_data)
@@ -530,7 +530,6 @@ sunone_folder_tree_removed (SunOneFolderTree *tree, SunOneAccount *account)
 	g_free (full_name);
 
 	remove_source (account, sunone_account_get_user (account), TRUE);
-	sunone_folder_tree_sync ();
 	sunone_connection_free_preferences (prefs);
 
 	page = sunone_folder_tree_no_view ();
@@ -1025,6 +1024,7 @@ sft_popup_rename_folder_response (GtkWidget *dialog, int response, SunOneFolderT
 out:
 	if (SUNONE_ERROR_IS_SUCCESSFUL (errcode)) {
 		sunone_folder_tree_rename_calendar (tree, account, calid, display_name);
+		sunone_folder_tree_sync ();
 	} else
 		error_handler (errcode);
 
@@ -1123,9 +1123,9 @@ sft_popup_delete_folder_response (GtkWidget *dialog, int response, SunOneFolderT
 	calid = sunone_util_get_calid_from_uri (physical_uri);
 
 	errcode = sunone_connection_deletecalendar (cnc, calid);
-	sunone_folder_tree_sync ();
 	if (SUNONE_ERROR_IS_SUCCESSFUL (errcode)) {
 		sunone_folder_tree_remove_calendar (tree, account, calid);
+		sunone_folder_tree_sync ();
 	} else {
 		error_handler (errcode);
 	}
@@ -1272,7 +1272,7 @@ sft_popup_login (EPopup *ep, EPopupItem *item, void *data)
 	sunone_folder_tree_removed (tree, account);
 	sunone_account_set_dont_ask_password (account, FALSE);
 	sunone_folder_tree_created (tree, account);
-
+	sunone_folder_tree_sync ();
 }
 
 static EPopupItem sft_popup_menu[] = {
@@ -1306,7 +1306,7 @@ sft_tree_popup (SunOneFolderTree *tree, GdkEvent *event)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean is_store, is_account, is_personal;
-	guint32 flags = ~0;
+	guint32 flags = ~0ul;
 
 	account = sunone_folder_tree_get_account (tree);
 
