@@ -23,14 +23,11 @@
 #include <libedataserver/e-util.h>
 #include <libecal/e-cal-time-util.h>
 #include <e-util/e-icon-factory.h>
-#include <e-util/e-time-utils.h>
 #include <e-util/e-gtk-utils.h>
 #include "sunone-itip-view.h"
 
 #define MEETING_ICON "stock_new-meeting"
 
-G_DEFINE_TYPE (SunOneItipView, sunone_itip_view, GTK_TYPE_HBOX);
-
 typedef struct  {
 	SunOneItipViewInfoItemType type;
 	char *message;
@@ -89,6 +86,8 @@ struct _SunOneItipViewPrivate {
 	gboolean rsvp_show;
 };
 
+G_DEFINE_TYPE (SunOneItipView, sunone_itip_view, GTK_TYPE_HBOX)
+
 static void
 format_date_and_time_x		(struct tm	*date_tm,
 				 struct tm      *current_tm,
@@ -870,11 +869,11 @@ sunone_itip_view_get_item_type (SunOneItipView *view)
 {
 	SunOneItipViewPrivate *priv;
 
-	g_return_val_if_fail (view != NULL, SUNONE_ITIP_VIEW_MODE_NONE);
-	g_return_val_if_fail (SUNONE_ITIP_IS_VIEW (view), SUNONE_ITIP_VIEW_MODE_NONE);
-	
+	g_return_val_if_fail (view != NULL, E_CAL_SOURCE_TYPE_LAST);
+	g_return_val_if_fail (SUNONE_ITIP_IS_VIEW (view), E_CAL_SOURCE_TYPE_LAST);
+
 	priv = view->priv;
-	
+
 	return priv->type;
 }
 
